<?php
    /*********************************************************************************
     * Zurmo is a customer relationship management program developed by
     * Zurmo, Inc. Copyright (C) 2012 Zurmo Inc.
     *
     * Zurmo is free software; you can redistribute it and/or modify it under
     * the terms of the GNU General Public License version 3 as published by the
     * Free Software Foundation with the addition of the following permission added
     * to Section 15 as permitted in Section 7(a): FOR ANY PART OF THE COVERED WORK
     * IN WHICH THE COPYRIGHT IS OWNED BY ZURMO, ZURMO DISCLAIMS THE WARRANTY
     * OF NON INFRINGEMENT OF THIRD PARTY RIGHTS.
     *
     * Zurmo is distributed in the hope that it will be useful, but WITHOUT
     * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
     * FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
     * details.
     *
     * You should have received a copy of the GNU General Public License along with
     * this program; if not, see http://www.gnu.org/licenses or write to the Free
     * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
     * 02110-1301 USA.
     *
     * You can contact Zurmo, Inc. with a mailing address at 113 McHenry Road Suite 207,
     * Buffalo Grove, IL 60089, USA. or at email address contact@zurmo.com.
     ********************************************************************************/

    // KEEP these in alphabetical order.
    // KEEP them indented correctly.
    // KEEP all the language files up-to-date with each other.
    // DON'T MAKE A MESS!
    return array(
        '(Unknown)'
            => '(Unbekannt)',
        '(Unnamed)'
            => '(Unbenannt)',
        '2D Donut Chart'
            => '2D Ringdiagramm',
        '2D Horizontal Bar Graph'
            => '2D Balkendiagramm',
        '2D Pie Chart'
            => '2D Kreisdiagramm',
        '2D Vertical Bar Graph'
            => '2D Säulendiagramm ',
        '3D Pie Chart'
            => '3D Kreisdiagramm',
        '3D Vertical Bar Graph'
            => '3D Säulendiagramm',
        '<strong>Zurmo</strong> is a <strong>Customer Relationship Management</strong> system by <strong>Zurmo Inc.</strong>'
            => '<strong>Zurmo</strong> ist ein <strong>Customer Relationship Management</strong> system von <strong>Zurmo Inc.</strong>',
        '<strong>Zurmo</strong> is licensed under the GPLv3.  You can read the license <a href="http://www.zurmo.org/license">here</a>.'
            => '<strong> Zurmo </strong> ist unter der GPLv3 lizenziert. Sie können die Lizenz <a href="http://www.zurmo.org/license"> hier lesen</a>',
        '<strong>Zurmo</strong> uses the following great Open Source tools and frameworks:'
            => '<strong>Zurmo</strong> nutzt die folgenden wunderbaren Open Source Tools und Frameworks:',
        'A large amount of data has been requested for export.  You will receive a notification with the download link when the export is complete.'
            => 'Viele Daten hat für den Export angefordert worden. Sie erhalten eine Benachrichtigung mit dem Download-Link, wenn der Export abgeschlossen ist.',
        'About Zurmo'
            => 'Über Zurmo',
        'Access Administration Tab'
            => 'Zugang Administration Tab',
        'Access Currency Configuration'
            => 'Zugang Währung Konfiguration',
        'Access Developer Tools'
            => 'Zugang Entwicklertools',
        'Access Failure'
            => 'Zugangsfehler',
        'Access Global Configuration'
            => 'Zugang Global Konfiguration',
        'Access Groups Tab'
            => 'Zugang Gruppen Tab',
        'Access Roles Tab'
            => 'Zugang Rollen Tab',
        'Active'
            => 'Aktiv',
        'Active currencies can be used when creating new records and as a default currency for a user.'
            => 'Aktive Währungen können bei der Erstellung neue Datensätze und als Standard-Währung für einen Benutzer',
        'Active languages can be used by users. The system language and any language in use by a user cannot be inactivated'
            => 'Aktive Sprachen können von den Benutzern verwendet werden. Das System Sprache und jeder Sprache in Verwendung durch einen Benutzer kann nicht inaktiviert werden',
        'Ad-hoc / Owner'
            => 'Ad-hoc / Besitzer',
        'Add Comment'
            => 'Kommentar hinzufügen',
        'Add criteria'
            => 'Kriterien hinzufügen',
        'Add Currency'
            => 'Währung hinzufügen',
        'Add new fields, remove ones you don\'t need and change the layout using Designer.'
            => 'Neue Felder hinzufügen, entfernan was nicht benötigt ist, und ändern das Layout mit Designer.',
        'Address'
            => 'Adresse',
        'Admin'
            => 'Admin', // Same Word Translated
        'Alert'
            => 'Alarm',
        'Allow'
            => 'Erlauben',
        'Amount'
            => 'Betrag',
        'An error has occurred. Please click'
            => 'Ein Fehler ist aufgetreten. Bitte klicken',
        'An error occured during login. Please try again.'
            => 'Fehler bei der Anmeldung. Bitte versuchen Sie es noch einmal.',
        'Any City'
            => 'Stadt',
        'Any Country'
            => 'Land',
        'Any Email Address'
            => 'E-Mail Adresse',
        'Any Invalid Email'
            => 'Ungültige E-Mail',
        'Any Opted Out Email'
            => 'Opted Out Email',
        'Any Postal Code'
            => 'Postleitzahl',
        'Any State'
            => 'Staat',
        'Any Street'
            => 'Straße',
        'Application is in maintenance mode, and only Super Administrators can access it.'
            => 'Die Anwendung ist im Wartungsmodus und nur Super Administratoren haben Zugriff.',
        'Application is in maintenance mode. Please try again later.'
            => 'Application ist im Wartungsmodus. Bitte versuchen Sie es später erneut.',
        'Application Name'
            => 'Systemname',
        'are required.'
            => 'Sind Erforderlich.',
        'Are you number one{spaceAndFirstName}? Find out how you size up to your colleagues on the Leaderboard.'
            => 'Bist du Nummer eins{spaceAndFirstName}? Vergleiche dich mit deinen Kollegen auf dem Leaderboard.',
        'Are you sure you want to delete this group?'
            => 'Sind Sie sicher, dass Sie dieser Gruppe entfernen möchten?',
        'Are you sure you want to delete this role?'
            => 'Sind Sie sicher, dass Sie diese Rolle entfernen möchten?',
        'Attachment'
            => 'Anhang',
        'Attachments'
            => 'Anhänge',
        'Audit Event'
            => 'Liste der Änderungen',
        'Audit Trail'
            => 'Änderungsprotokoll',
        'Automotive'
            => 'Autoindustrie',
        'Banking'
            => 'Banking', // Same Word Translated
        'Business Services'
            => 'Handelsdienstleistungen',
        'by {ownerStringContent}'
            => 'von {ownerStringContent}',
        'Cache has been successfully cleaned.'
            => 'Cache wurde erfolgreich gereinigt.',
        'Changes to active currencies saved successfully.'
            => 'Änderungen an aktiven Währungen erfolgreich geändert.',
        'Changes to active languages saved successfully.'
            => 'Änderungen an aktiven Sprachen erfolgreich geändert.',
        'Chart Type'
            => 'Diagrammtyp',
        'City'
            => 'Stadt',
        'Clear Cache'
            => 'Cache löschen',
        'Click on the Map link on records to see the customer location on Google Maps.'
            => 'Klickst du auf den Link, um den Lageplan mit Google Maps zu sehen.',
        'Close'
            => 'schließen',
        'Code'
            => 'Code', // Same Word Translated
        'Comment'
            => 'Kommentar',
        'Configuration'
            => 'Konfiguration',
        'Configure'
            => 'Konfigurieren',
        'Convert'
            => 'Konvertieren',
        'Copyright &#169; Zurmo Inc., 2012. All Rights reserved.'
            => 'Copyright © Zurmo Inc., 2012. Alle Rechte vorbehalten.',
        'Could not remove relation.'
            => 'Unfähig, die Beziehung zu löschen.',
        'Could not save relation.'
            => 'Unfähig, die Beziehung zu retten.',
        'Could not use this API call for HAS_ONE relationships.'
            => 'Unmöglich, diese API-Aufruf für die Beziehungen HAS_ONE zu verwenden.',
        'Country'
            => 'Land',
        'Create Group'
            => 'Gruppe erstellen',
        'Create Groups'
            => 'Gruppen erstellen',
        'Create Role'
            => 'Role erstellen',
        'Create Roles'
            => 'Rollen erstellen',
        'Created'
            => 'Erstellt',
        'created by {ownerStringContent}'
            => 'erstellt von {ownerStringContent}',
        'Criteria Selected <span class="icon-clear">Z</span>'
            => 'Kriterien ausgewählt <span class="icon-clear">Z</span>',
        'Currencies: Create'
            => 'Währungen: erstellen',
        'Currencies: List'
            => 'Währungen: List',
        'Currency'
            => 'Währung',
        'Currency Configuration'
            => 'Währung Konfiguration',
        'Currency in use.'
            => 'Währung in Verwendung',
        'Currency Rates Update Job'
            => 'Wechselkurs Aktualisierungen',
        'Currency Value'
            => 'Wert der Währung',
        'Custom data updated successfully.'
            => 'Benutzerdefinierte Daten erfolgreich aktualisiert.',
        'Customer'
            => 'Kunde',
        'Dashboard portlet list page size'
            => 'Anzahl der Elemente pro Seite in Listen Portlets',
        'Data'
            => 'Daten',
        'Database upgrade not completed. Please try again later.'
            => 'Datenbank-Upgrade nicht abgeschlossen. Bitte versuchen es später erneut.',
        'days'
            => 'Tage',
        'Dead'
            => 'Tot',
        'Decide who can view and edit a record, set Group rights and permissions.'
            => 'Wer hat die Berechtigung zum Anzeigen und Bearbeiten eines Datensatzes und wer kann Gruppe Rechte und Berechtigungen festlegen.',
        'Delete Group'
            => 'Gruppe löschen',
        'Delete Groups'
            => 'Gruppen löschen',
        'Delete Role'
            => 'Rolle löschen',
        'Delete Roles'
            => 'Rollen löschen',
        'Deny'
            => 'Verweigern',
        'Department'
            => 'Abteilung',
        'Description'
            => 'Beschreibung',
        'Developer Tools'
            => 'Entwicklertools',
        'Dr.'
            => 'Dr.', // Same Word Translated
        'Due On'
            => 'Fällig am',
        'Edit charts on the dashboard by clicking the config icon in the top right of each portlet.'
            => 'Durch Klicken auf die Config-Icon in der rechten oberen Ecke jedes Portlet ermöglicht es, Diagramme auf dem Dashboard zu bearbeiten.',
        'Email'
            => 'E-Mail',
        'Email Address'
            => 'E-Mail Adresse',
        'Enable game notification popup'
            => 'Aktivieren Spiel Mitteilung popup',
        'Energy'
            => 'Energieindustrie',
        'Event Name'
            => 'Ereignisname',
        'every'
            => 'jeder',
        'Everyone'
            => 'Alle',
        'Fields with'
            => 'Felder mit',
        'File Content'
            => 'Dateiinhalt',
        'File failed to upload. The file is empty.'
            => 'Datei konnte nicht hochgeladen. Die Datei ist leer.',
        'Files'
            => 'Dateien',
        'Filter By Created User'
            => 'Filtern nach erstellt Benutzer',
        'Filtered Lists'
            => 'Gefilterte Listen',
        'Financial Services'
            => 'Finanzdienstleistung',
        'Find what you need quickly using the global search at the top of the screen.'
            => 'Verwenden Sie die globale Suche am oberen Bildschirmrand zu finden, was du schnell brauchst.',
        'First Name'
            => 'Vorname',
        'Forums'
            => 'Forums', // Same Word Translated
        'Global and Basic Search Fields'
            => 'Globale und einfache Suche Felder',
        'Global Configuration'
            => 'Globale Konfiguration',
        'Global configuration saved successfully.'
            => 'Globale Konfiguration wurde erfolgreich gespeichert.',
        'Global search'
            => 'Globale Suche',
        'Go to Search'
            => 'Zugang Suche',
        'Got questions{spaceAndFirstName}? Find answers in the Zurmo Wiki.'
            => 'Hast du Fragen{spaceAndFirstName}? Antworten auf die Zurmo Wiki.',
        'Group'
            => 'Gruppe',
        'Group Module Permissions'
            => 'Gruppe Modul Berechtigungen',
        'Group Policies'
            => 'Gruppenrichtlinien',
        'Group Rights'
            => 'Gruppe Rechte',
        'Groups'
            => 'Gruppen',
        'Groups Home'
            => 'Gruppen Startseite',
        'here'
            => 'hier',
        'Home'
            => 'Startseite',
        'If there is new metadata to load using CustomManagement, use this option.'
            => 'Diese Option verwenden, wenn es neue Metadaten mit CustomManagement zu laden gibt.',
        'In Progress'
            => 'In Bearbeitung',
        'In the case where you have reloaded the database, some cached items might still exist. This is a way to clear that cache.'
            => 'Wenn die Datenbank neu geladen wurde, könnten einige zwischengespeicherten Elemente noch vorhanden sein Dies ist ein Weg, um die Cache zu löschen.',
        'Inbound Call'
            => 'Eingehende Anrufe',
        'Incorrect username or password.'
            => 'Falsche Benutzername oder Kennwort.',
        'Industry'
            => ' Industrieller Bereich',
        'Inherited - All'
            => 'Vererbte - Alle',
        'Inherited - Allow'
            => 'Vererbte - Erlaubt',
        'Inherited - Deny'
            => 'Vererbte - Verweigern',
        'Inherited - No'
            => 'Vererbte - Nein',
        'Inherited - Owner Only'
            => 'Vererbte - Nur Besitzer',
        'Inherited - Yes'
            => 'Vererbte - Ja',
        'Inherited Value:'
            => 'Vererbte Wert:',
        'Insurance'
            => 'Versicherung',
        'Invalid currency code'
            => 'Ungültige Währungscode',
        'Invalid username or password.'
            => 'Ungültiger Benutzername oder Kennwort.',
        'Is Invalid'
            => 'ist ungültig',
        'Job Title'
            => 'Berufsbezeichnung',
        'Label must be all lowercase.'
            => 'Kennsatz muss alle Kleinbuchstaben sein',
        'Label must not be empty.'
            => 'Kennsatz darf nicht leer sein',
        'Label must not contain any special characters.'
            => 'Kennsatz darf keine Sonderzeichen.',
        'Language'
            => 'Sprache',
        'Languages'
            => 'Sprachen',
        'Languages: List'
            => 'Sprachen: Liste',
        'Last Name'
            => 'Nachname',
        'Last Updated'
            => 'Aktualisiert',
        'Latitude'
            => 'Breite',
        'Let Zurmo crunch the numbers, add calculated fields to your records in Designer.'
            => 'Zurmo kann dein Zahlenfresser sein wenn du berechnete Felder in Designer hinzufügen.',
        'List Filters'
            => 'Liste Filtern',
        'List page size'
            => 'Liste Seitengröße',
        'List View'
            => 'Listenansicht',
        'Load'
            => 'Laden',
        'Load a saved search'
            => 'Laden einer gespeicherte Suche',
        'Longitude'
            => 'Länge',
        'Manage Active Languages'
            => 'Verwaltung der aktiven Sprachen',
        'Manage Currency Configuration'
            => 'Verwaltung der Währung Konfiguration',
        'Manage Global Configuration'
            => 'Verwaltung der Globale Konfiguration',
        'Manage Groups'
            => 'Verwaltung der Gruppen',
        'Manage Roles'
            => 'Verwaltung der Rollen',
        'Manufacturing'
            => 'Herstellung',
        'map'
            => 'karte',
        'Member'
            => 'Mitglied',
        'Member Of'
            => 'Mitglied von',
        'Members'
            => 'Mitglieder',
        'Menu'
            => 'Menü',
        'Missing Record'
            => 'tei fehlt',
        'Missing Required Fields'
            => 'Fehlende Pflichtangaben',
        'Mobile Phone'
            => 'Mobiltelefon',
        'Model was not created.'
            => 'Das Modell wurde nicht erstellt.',
        'Model was not updated.'
            => 'Das Modell wurde nicht aktualisiert.',
        'Model was updated, but there were issues with relations.'
            => 'Modell wurde aktualisiert aber es gab Probleme mit der Beziehungen.',
        'Modify Structure'
            => 'Struktur Ändern',
        'Module Name - Plural'
            => 'Modul Name - Plural',
        'Module Name - Plural (lowercase)'
            => 'Modul Name - Plural (Kleinbuchstaben)',
        'Module Name - Singular'
            => 'Modul Name - Singular',
        'Module Name - Singular (lowercase)'
            => 'Modul Name - Singular (Kleinbuchstaben)',
        'Module Permissions'
            => 'Modul Berechtigungen',
        'Module Permissions Saved Successfully.'
            => 'Modul Berechtigungen erfolgreich gespeichert.',
        'Mr.'
            => 'Herr',
        'Mrs.'
            => 'Frau',
        'Ms.'
            => 'Frau',
        'My List Configuration View'
            => 'Meine Liste Konfigurationsansicht',
        'Need help{spaceAndFirstName}, why not ask a question in the forum?'
            => 'Brauchst du Hilfe{spaceAndFirstName}? Stell deine Fragen in den Foren.',
        'Need to see the big picture? Click Roll-Up to see activities from related records.'
            => 'Aktivieren Roll Up, um Aktivitäten von verknüpften Datensätzen zu sehen.',
        'Need to update multiple records at once? Select them from the list and hit the Update button.'
            => 'Brauchst du mehrere Datensätze zu aktualisieren? Wähle aus der Liste und die Aktualisierung Taste drücken.',
        'Never'
            => 'Nie',
        'New'
            => 'Neu',
        'No Results Found'
            => 'Keine Ergebnisse gefunden',
        'Non Members'
            => 'Nichtmitgliedern',
        'Not Set'
            => 'Nicht eingestellt',
        'Not Set - Ad-hoc / Owner'
            => 'Nicht eingestellt - Ad-hoc / Owner',
        'Notifications'
            => 'Benachrichtigungen',
        'Office Fax'
            => 'Büro Fax',
        'Office Phone'
            => 'Bürotelefon',
        'Oh no!'
            => 'Ach nein!',
        'Once a day, early in the morning.'
            => 'Einmal am Tag, früh am Morgen.',
        'Once a week, early in the morning.'
            => 'Einmal in der Woche, früh am Morgen.',
        'Only Items I Own'
            => 'Nur meine Objekte',
        'Opt Out'
            => 'Opt Out', // Same Word Translated
        'owned by {ownerStringContent}'
            => 'besitz von {ownerStringContent}',
        'Owner'
            => 'Besitzer',
        'Owner and users in'
            => 'Besitzer und Users in',
        'Owner Only'
            => 'Nur Besitzer',
        'Parent Group'
            => 'Übergeordnete Gruppe',
        'Parent Role'
            => 'übergeordneten Rolle',
        'Parlez vous Français{spaceAndFirstName}? Choose your preferred language in your My Profile area.'
            => 'Parlez vous français{spaceAndFirstName}? Die gewünschte Sprache kann man in meinem Profil ausgewählt.',
        'Password'
            => 'Kennwort',
        'Permissions'
            => 'Berechtigungen',
        'Permitable'
            => 'Erlaubt',
        'Please provide data.'
            => 'Bitte geben Sie die Daten.',
        'Please resolve the following issues for {modelString}:'
            => 'Bitte behebe die folgenden Probleme für {modelString}:',
        'Please use FireFox, Chrome, or Internet Explorer.'
            => 'Bitte benutzen Sie FireFox, Chrome oder Internet Explorer.',
        'Policies'
            => 'Richtlinien',
        'Policies Saved Successfully.'
            => 'Richtlinien erfolgreich gespeichert.',
        'Popup list page size'
            => 'Popup-Liste Seitengröße',
        'Post to Profile'
            => 'Teilen auf deinem Profil ',
        'Postal Code'
            => 'Postleitzahl',
        'Primary Address'
            => 'Hauptadresse',
        'Primary Email'
            => 'Haupt-Email',
        'Qualified'
            => 'Qualifiziert',
        'Rate to'
            => 'Wechselkurs am',
        'Rate To Base'
            => 'Wechselkurs',
        'Read'
            => 'Lesen',
        'Read permissions rebuild complete.'
            => 'Leseberechtigungen Wiederaufbau abgeschlossen',
        'Recently Viewed'
            => 'Zuletzt angesehen',
        'Recently Viewed lets you jump back to any records you have looked at lately.'
            => 'Zuletzt Angesehen bringts du zurück auf Datensätze, die du vor kurzem gesehen haben.',
        'Recycled'
            => 'Recycled', // Same Word Translated
        'Remember me next time'
            => 'Benutzername Behalten',
        'Remember{spaceAndFirstName}, the Audit Trail shows you what has changed on a record and who changed it.'
            => 'Das Update-Log zeigt die Historie der Änderungen einschließlich der Benutzername, der hat sich geändert.',
        'Retail'
            => 'Einzelhandel',
        'Return to Admin Menu'
            => 'Zurück zu Admin Menü',
        'Rights'
            => 'Rechte',
        'Rights and Permissions'
            => 'Berechtigungen und Sicherheit Rechte',
        'Rights Saved Successfully.'
            => 'Rechte erfolgreich gespeichert.',
        'Role'
            => 'Rolle',
        'Roles'
            => 'Rollen',
        'Roles Home'
            => 'Berechtigungen und Sicherheit Rechte',
        'Run'
            => 'Laufen',
        'Salutation'
            => 'Begrüßung',
        'Save Changes'
            => 'Änderungen speichern',
        'Save search'
            => 'Suche speichern',
        'Save yourself time and click the pencil icon to jump right in and edit your record.'
            => 'Zeit sparen! Klickst du auf das Bleistift-Symbol, um deinen Eintrag zu bearbeiten.',
        'Search'
            => 'Suche',
        'Search by name, phone, or e-mail'
            => 'Suche nach Name, Telefon oder e-mail',
        'Secondary Address'
            => 'Sekundäre Adresse',
        'Secondary Email'
            => 'Sekundäre E-Mail',
        'Securable Item'
            => 'Sicherbare Artikel',
        'Security Overview'
            => 'Sicherheit',
        'See more search results by clicking the down arrow at the bottom of the screen.'
            => 'Klickst du auf den Pfeil am unteren Rand des Bildschirms, um mehr Ergebnisse zu sehen.',
        'Select a field'
            => 'Ein Feld wählen',
        'Select a Group'
            => 'Wählen Sie eine Gruppe',
        'Select a Parent Group'
            => 'Wählen Sie einen übergeordneten Gruppe',
        'Select a Parent Role'
            => 'Wählen Sie eine übergeordnete Rolle',
        'Select a Role'
            => 'Wählen Sie eine Rolle',
        'Self-Generated'
            => 'Selbstgeneriert',
        'Send a test email to'
            => 'Senden eine Testnachricht  zu',
        'Set your preferences, password, and contact details in your My Profile area.'
            => 'Ändern deine Einstellungen, Kennwort und Kontaktdaten im Mein Profil.',
        'Settings'
            => 'Einstellungen',
        'Shipping Address'
            => 'Liefer-Adresse',
        'Sign in'
            => 'Anmelden',
        'Sign in required.'
            => 'Login erforderlich.',
        'Sign out'
            => 'Abmelden',
        'Sign out failed.'
            => 'Fehler bei der Abmeldung.',
        'Size'
            => 'Größe',
        'skipped because you do not have sufficient permissions.'
            => 'Übergesprungen weil Sie nicht die richtige Berechtigung haben. ',
        'Sorry! Your browser is not supported.'
            => 'Sorry! Ihr Browser ist nicht unterstützt',
        'Source'
            => 'Quelle',
        'Specified custom field name was invalid.'
            => 'Der Name der benutzerdefinierte Feld ist ungültig.',
        'Stage'
            => 'Stufe',
        'Standard Fields'
            => 'Standard-Felder',
        'State'
            => 'Staat',
        'Status'
            => 'Status', // Same Word Translated
        'Street 1'
            => 'Straße 1',
        'Street 2'
            => 'Straße 2',
        'Sublist page size'
            => 'Unterliste Seitengröße',
        'Successfully updated'
            => 'Erfolgreich aktualisiert',
        'Summary'
            => 'Zusammenfassung',
        'Super Administrators'
            => 'Super Administratoren',
        'Tag Cloud fields allow you to tag records with values so that you can easily find them later.'
            => 'Mit Tag Cloud Felder kann man Datensätze mit Werten  markieren, so man sie leicht später finden kann.',
        'Technology'
            => 'Technologie',
        'The currency rate web service says this currency code is invalid even though zurmo says it is valid. The rate could not be automatically updated.'
            => 'Der Wechselkurs Web-Service behauptet dass dieser Währung ist ungültig, obwohl zurmo behauptet, es gültig ist. Der Wechselkurs war nicht automatisch aktualisiert.',
        'The currency rate web service was unavailable. The rate could not be automatically updated.'
            => 'Der Wechselkurs Web-Service war nicht verfügbar. Der Wechselkurs konnte nicht automatisch aktualisiert werden',
        'The currency was not removed because it is in use.'
            => 'Die Währung wurde nicht gelöscht, weil es in Gebrauch ist.',
        'The default value is {policyDefault}'
            => 'Der Standardwert ist {policyDefault}',
        'The ID specified was invalid.'
            => 'ID ist ungültig.',
        'The Import Wizard helps get your data into the system easily, find it under the config icon (that\'s the cog in the top right).'
            => 'Der Import-Assistent hilft man Daten in das System leicht bekommen. Es wird unter dem Config-Symbol gefunden.',
        'The Notifications speech bubble keeps you up to date on important events.'
            => 'Die Benachrichtigungen Sprechblase hält dich auf dem neuesten über wichtige Ereignisse.',
        'The record you are trying to access does not exist.'
            => 'Der Datensatz existiert nicht.',
        'The related model ID specified was invalid.'
            => 'Die zugehörige Modell-ID angegeben war ungültig.',
        'The status specified is invalid.'
            => 'Der Status ist ungültig.',
        'There are no recently viewed items.'
            => 'Es gibt keine kürzlich angesehenen Artikel',
        'There are required fields missing from the following layout: {view}.  Please contact your administrator.'
            => 'Pflichtfelder fehlen in der folgenden Aufbau: {view}. Bitte kontaktieren Sie Ihren Administrator',
        'There is no data to export.'
            => 'Es gibt keine Daten zu exportieren.',
        'This action is only available in debug mode.'
            => 'Diese Aktion ist nur im Debug-Modus zur Verfügung.',
        'This is <strong>version {zurmoVersion}</strong> of <strong>Zurmo</strong>.'
            => 'Dies ist <strong>version {zurmoVersion}</strong> von <strong>Zurmo</strong>.',
        'This name is reserved. Please pick a different name.'
            => 'Dieser Name ist reserviert. Bitte wählen Sie einen anderen Namen.',
        'Time zone'
            => 'Zeitzone',
        'Title'
            => 'Titel',
        'to continue to the home page. If the error persists please contact your administrator.'
            => 'auf der Homepage weiter. Falls der Fehler bestehen wenden Sie sich bitte an Ihren Administrator.',
        'Tradeshow'
            => 'Messe',
        'Type a currency code or name to search.'
            => 'Geben Sie eine Währung oder Name zu suchen.',
        'Unsupported action.'
            => 'Nicht unterstützte Aktion.',
        'Update'
            => 'Aktualisierung',
        'Update Custom Data'
            => 'Custom Data Aktualisieren',
        'Updated'
            => 'Aktualisiert',
        'Upload attachments to a record by clicking "More Options" when adding a note.'
            => '"Weitere Optionen" klicken beim Hinzufügen einer Notiz um eine Anhang zu hochladen.',
        'User Membership'
            => 'Benutzer Mitgliedschaft',
        'User Membership Saved Successfully.'
            => 'Benutzer Mitgliedschaft erfolgreich gespeichert',
        'Username'
            => 'Benutzername',
        'Users'
            => 'Users',
        'Value'
            => 'Wert',
        'Values'
            => 'Werte',
        'Visit <strong>Zurmo Inc.</strong> at {url}.'
            => 'Besuchen Sie <strong>Zurmo Inc.</strong> unter {url}',
        'Visit the <strong>Zurmo Open Source Project</strong> at {url}.'
            => 'Besuchen Sie die <strong>Zurmo Open Source Project</strong> unter {url}.',
        'Want to export your data directly to Excel? Search for the data you need and hit the Export button.'
            => 'Um deine Daten nach Excel zu exportieren, führst du eine Suche und klickst du auf "Export".',
        'Website'
            => 'Webseite',
        'Welcome'
            => 'Herzlich Willkommen',
        'What is this?'
            => 'Was ist das?',
        'Who can read and write'
            => 'Wer darf lesen und schreiben?',
        'Who can read and write - Default'
            => 'Wer darf lesen und schreiben?',
        'Word of Mouth'
            => 'Mund zu Mund Propaganda',
        'Write'
            => 'schreiben',
        'You can add relations only for HAS_MANY and MANY_MANY relations.'
            => 'Du kannst Beziehungen nur für HAS_MANY und MANY_MANY Beziehungen hinzufügen.',
        'You have tried to access a page you do not have access to.'
            => 'Sie haben keinen Zugriff auf die Seite.',
        'You must have at least one active currency.'
            => 'Sie müssen mindestens eine aktive Währung haben.',
        'Your RedBean version is currentVersion and it should be acceptableVersion.'
            => 'Ihre RedBean Version ist currentVersion und sollte acceptableVersion sein',
        'Your Yii version is currentVersion and it should be acceptableVersion.'
            => 'Ihre Yii-Version ist currentVersion und sollte acceptableVersion',
        'ZurmoCRM'
            => 'ZurmoCRM', // Same Word Translated
        '{modelString} is already connected to this record.'
            => '{modelString} ist bereits auf diesen Datensatz verbunden.',
        '{url} (installed with Yii)'
            => '{url} (installed with Yii)', // Same Word Translated
        '{url} (version {version} is installed)'
            => '{url} (version {version} is installed)', // Same Word Translated
    );
?>
